/*
 * libopensync - A synchronization framework
 * Copyright (C) 2004-2006  Armin Bauer <armin.bauer@desscon.com>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 * 
 */
 
#ifndef OPENSYNC_MAPPING_VIEW_H_
#define OPENSYNC_MAPPING_VIEW_H_

/*OSyncMappingView *osync_mapping_view_new(OSyncError **error);
OSyncMappingView *osync_mapping_view_ref(OSyncMappingView *view);
void osync_mapping_view_unref(OSyncMappingView *view);

osync_bool osync_mapping_view_add_entry(OSyncMappingView *view, OSyncChange *change, OSyncError **error);
int osync_mapping_view_num_entries(OSyncMappingView *view);
OSyncMappingEntry *osync_mapping_view_nth_entry(OSyncMappingView *view, int nth);

int osync_mapping_view_num_unmapped(OSyncMappingView *view);
OSyncMappingEntry *osync_mapping_view_nth_unmapped(OSyncMappingView *view, int nth);
void osync_mapping_view_remove_unmapped(OSyncMappingView *view, OSyncMappingEntry *entry);*/

#endif /*OPENSYNC_MAPPING_VIEW_H_*/
